##  Introduction
There are various ways to create fact sheets in SAP LeanIX: you can create them individually in the inventory, in bulk through Excel file imports, or automatically through discoveries and the reference catalog.
This guide covers the creation of fact sheets in inventory. To learn about creating fact sheets through spreadsheet import, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file."). For information on discoveries and integrations, see [Discoveries and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.").
Users with appropriate permissions, such as members and administrators by default, can create fact sheets. Admins can configure this permission to include other user roles, including custom roles. They can also modify the permission for each fact sheet type to restrict or expand creation rights. To learn more, see [Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Configure fact sheet permissions for non-admin user roles.").
